==> xsd.doc_1.0.2_20030326_0335VL.zip: src/org/eclipse/xsd/impl/type/XSDGMonthDayType.java <==
/**
 * <copyright>
 *
 * Copyright (c) 2002 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors: 
 *   IBM - Initial API and implementation
 *
 * </copyright>
 *
 * plugins/org.eclipse.xsd/src/org/eclipse/xsd/impl/type/XSDGMonthDayType.java, xsd, org.eclipse.102, 20030326_0335VL
 * @version 1.2 3/26/03
 */
package org.eclipse.xsd.impl.type;


import org.eclipse.xsd.XSDPlugin;

import org.eclipse.xsd.impl.XSDSimpleTypeDefinitionImpl;

import org.apache.xerces.impl.dv.InvalidDatatypeValueException;
import org.apache.xerces.impl.dv.xs.MonthDayDV;



public class XSDGMonthDayType extends XSDAnySimpleType
{
  public static class AccessibleMonthDayDV extends MonthDayDV
  {
    public String dateToString(int[] monthDay)
    {
      return super.dateToString(monthDay);
    }

    public short compareDates(int[] monthDay1, int[] monthDay2, boolean strict) 
    {
      return super.compareDates(monthDay1, monthDay2, strict);
    }
  }

  protected static final AccessibleMonthDayDV monthDayDV = new AccessibleMonthDayDV();

  public boolean isValidLiteral(String normalizedLiteral)
  {
    try
    {
      monthDayDV.getActualValue(normalizedLiteral, null);
      return true;
    }
    catch (InvalidDatatypeValueException exception)
    {
      return false;
    }
  }

  public Object getValue(String normalizedLiteral)
  {
    try
    {
      return monthDayDV.getActualValue(normalizedLiteral, null);
    }
    catch (InvalidDatatypeValueException exception)
    {
      return null;
    }
  }

  public String getCanonicalLiteral(Object value)
  {
    return value == null ? null : monthDayDV.dateToString((int[]) value);
  }

  public int compareValues(Object value1, Object value2)
  {
    return monthDayDV.compareDates((int []) value1, (int [])value2, true);
  }
}

==> xsd.doc_1.1.0_20030620_1105VL.zip: src/org/eclipse/xsd/impl/type/XSDGMonthDayType.java <==
/**
 * <copyright>
 *
 * Copyright (c) 2002 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors: 
 *   IBM - Initial API and implementation
 *
 * </copyright>
 *
 * plugins/org.eclipse.xsd/src/org/eclipse/xsd/impl/type/XSDGMonthDayType.java, xsd, org.eclipse.dev, 20030620_1105VL
 * @version 1.3 6/20/03
 */
package org.eclipse.xsd.impl.type;


import org.eclipse.xsd.XSDPlugin;

import org.eclipse.xsd.impl.XSDSimpleTypeDefinitionImpl;

import org.apache.xerces.impl.dv.InvalidDatatypeValueException;
import org.apache.xerces.impl.dv.xs.MonthDayDV;



public class XSDGMonthDayType extends XSDAnySimpleType
{
  public static class AccessibleMonthDayDV extends MonthDayDV
  {
    public String dateToString(int[] monthDay)
    {
      return super.dateToString(monthDay);
    }

    public short compareDates(int[] monthDay1, int[] monthDay2, boolean strict) 
    {
      return super.compareDates(monthDay1, monthDay2, strict);
    }
  }

  protected static final AccessibleMonthDayDV monthDayDV = new AccessibleMonthDayDV();

  public boolean isValidLiteral(String normalizedLiteral)
  {
    try
    {
      monthDayDV.getActualValue(normalizedLiteral, null);
      return true;
    }
    catch (InvalidDatatypeValueException exception)
    {
      return false;
    }
  }

  public Object getValue(String normalizedLiteral)
  {
    try
    {
      return new IntSequence(this, (int [])monthDayDV.getActualValue(normalizedLiteral, null));
    }
    catch (InvalidDatatypeValueException exception)
    {
      return null;
    }
  }

  public String getCanonicalLiteral(Object value)
  {
    return value == null ? null : monthDayDV.dateToString(((IntSequence)value).getInts());
  }

  public int compareValues(Object value1, Object value2)
  {
    return monthDayDV.compareDates(((IntSequence)value1).getInts(), ((IntSequence)value2).getInts(), true);
  }
}
